@@ -16,6 +16,12 @@ arb_mat_mul_classical(arb_mat_t C, const arb_mat_t A, const arb_mat_t B, slong p
 {
     slong ar, ac, br, bc, i, j, k;
 
+    if (A == B)
+    {
+        arb_mat_sqr_classical(C, A, prec);
+        return;
+    }
+
     ar = arb_mat_nrows(A);
     ac = arb_mat_ncols(A);
     br = arb_mat_nrows(B);
